@@ -1,5 +1,9 @@
 from ...core import JavaScript
-from ...internal.constants import SEAMLESS_ELEMENT_ATTRIBUTE, SEAMLESS_INIT_ATTRIBUTE
+from ...internal.constants import (
+    SEAMLESS_ELEMENT_ATTRIBUTE,
+    SEAMLESS_INIT_ATTRIBUTE,
+    SEAMLESS_INIT_ASYNC_ATTRIBUTE,
+)
 
 
 def init_transformer():
@@ -11,6 +15,8 @@ def init_transformer():
         element.props[SEAMLESS_INIT_ATTRIBUTE] = (
             element.props.get(SEAMLESS_INIT_ATTRIBUTE, "") + source.code
         )
+        if source.async_:
+            element.props[SEAMLESS_INIT_ASYNC_ATTRIBUTE] = True
         del element.props[key]
 
     return matcher, transformer
@@ -26,7 +32,7 @@ def js_transformer():
         element.props[SEAMLESS_ELEMENT_ATTRIBUTE] = True
         element.props[SEAMLESS_INIT_ATTRIBUTE] = (
             element.props.get(SEAMLESS_INIT_ATTRIBUTE, "")
-            + f"\nthis.addEventListener('{event_name}', (event) => {{{source.code}}});"
+            + f"\nthis.addEventListener('{event_name}', {'async' if source.async_ else ''}(event) => {{{source.code}}});"
         )
         del element.props[key]
 
