@@ -1,5 +1,4 @@
 from typing import Generic, TypeVar, Unpack, TYPE_CHECKING
-from ..extra.transformers import transformer_for
 
 if TYPE_CHECKING:
     from ..types.styling.css_properties import CSSProperties
@@ -41,8 +40,3 @@ class StyleObject:
 
     def __getattr__(self, name: str):
         return StyleObject._StyleProperty(self, name)
-
-
-@transformer_for(lambda _, value: isinstance(value, StyleObject))
-def style_transformer(key, value: StyleObject, props):
-    props[key] = value.to_css()
